@@ -553,8 +553,7 @@ class Douglas_peucker(object):
             pointlist[i] = self.DouglasPeucker(pointlist[i], self.EPSILON)
         handwritten_data.set_pointlist(pointlist)
         # This might have duplicated points! Filter them!
-        alg = Remove_points()
-        alg(handwritten_data)
+        handwritten_data.preprocessing([Remove_points()])
 
 
 class Stroke_connect(object):
